@@ -1,7 +1,7 @@
 import json
 from typing import List
 from pyspark.sql.functions import *
-from pyspark.sql.types import StructType,StructField,StringType,BooleanType,DoubleType,LongType,DecimalType, IntegerType, DateType, ShortType, TimestampType
+from pyspark.sql.types import StructType,StructField,StringType,BooleanType,DoubleType,LongType,DecimalType, IntegerType, DateType, ShortType, TimestampType, FloatType
 from motordecalidad.constants import *
 from motordecalidad.utilities import *
 import datetime
@@ -9,7 +9,7 @@ import time
 from motordecalidad.rules import *
 
 
-print("Motor de Calidad Version Release 1.9.2")
+print("Motor de Calidad Version Release 1.9.15")
 
 # Main function, Invokes all the parameters from the json, Optionally filters, starts the rule validation
 # Writes and returns the summary of the validation 
@@ -21,10 +21,10 @@ def startValidation(inputspark,config,dfltPath=""):
     spark = inputspark
     dbutils = get_dbutils(spark)
     print("Inicio de validacion")
-    object,output,country,project,entity,domain,subDomain,segment,area,rules,error,filtered,dataDate,validData,finalData,sendEmail, email = extractParamsFromJson(config)
+    object,output,country,project,entity,domain,subDomain,segment,area,rules,error,filtered,dataDate,validData,finalData, email = extractParamsFromJson(config)
     filteredObject = applyFilter(object,filtered)
     registerAmount = filteredObject.count()
-    validationData = validateRules(filteredObject,rules,registerAmount,entity,project,country,domain,subDomain,segment,area,error,dataDate,validData,finalData,sendEmail, email,output)
+    validationData = validateRules(filteredObject,rules,registerAmount,entity,project,country,domain,subDomain,segment,area,error,dataDate,validData,finalData, email,output)
     writeDf(validationData, output)
     return validationData
 
@@ -46,13 +46,14 @@ def extractParamsFromJson(config):
     error = data.get(JsonParts.Error)
     filtered = data.get(JsonParts.Filter)
     finalData = data.get(JsonParts.Data)
-    sendEmail = input.get(JsonParts.SendEmail)
     email = input.get(JsonParts.Email)
-
-    entityDf = readDf(input)
+    try:
+        entityDf = readDf(input)
+    except:
+        raise Exception("Error en la lectura del fichero")
     rules = data.get(JsonParts.Rules)
     print("Extraccion de JSON completada")
-    return entityDf,output,country,project,entity,domain,subDomain,segment,area,rules,error,filtered,dataDate,validData,finalData,sendEmail,email
+    return entityDf,output,country,project,entity,domain,subDomain,segment,area,rules,error,filtered,dataDate,validData,finalData,email
 
 # Function that reads the input File
 def readDf(input):
@@ -150,17 +151,20 @@ def writeDf(object:DataFrame,output):
                 object.coalesce(One).write.partitionBy(*partitions).mode("overwrite").option("partitionOverwriteMode", "dynamic").option("delimiter",str(output.get(JsonParts.Delimiter))).option("header",header).format("com.databricks.spark.csv").save(str(output.get(JsonParts.Path).format( 
                     country = dbutils.widgets.get('country'),
                     year = dbutils.widgets.get('year'),
-                    month = dbutils.widgets.get('month'))))
+                    month = dbutils.widgets.get('month'),
+                    day = dbutils.widgets.get("day"))))
             else:
                 object.coalesce(One).write.mode("overwrite").option("partitionOverwriteMode", "dynamic").option("delimiter",str(output.get(JsonParts.Delimiter))).option("header",header).format("com.databricks.spark.csv").save(str(output.get(JsonParts.Path).format( 
                     country = dbutils.widgets.get('country'),
                     year = dbutils.widgets.get('year'),
-                    month = dbutils.widgets.get('month'))))
+                    month = dbutils.widgets.get('month'),
+                    day = dbutils.widgets.get("day"))))
         except:
             object.coalesce(One).write.mode("overwrite").option("partitionOverwriteMode", "dynamic").option("delimiter",str(output.get(JsonParts.Delimiter))).option("header",header).format("com.databricks.spark.csv").save(str(output.get(JsonParts.Path).format( 
                 country = dbutils.widgets.get('country'),
                 year = dbutils.widgets.get('year'),
-                month = dbutils.widgets.get('month'))))
+                month = dbutils.widgets.get('month'),
+                    day = dbutils.widgets.get("day"))))
     else:
         spark.conf.set(output.get(JsonParts.Account),output.get(JsonParts.Key))
         header:bool = output.get(JsonParts.Header)
@@ -196,6 +200,8 @@ def createErrorData(object:DataFrame) :
             columnsTypes.append(ShortType())
         elif dt[One] == "timestamp" :
             columnsTypes.append(TimestampType())
+        elif dt[One] == "float" :
+            columnsTypes.append(FloatType())
     columnsTypes.extend([StringType(),StringType()])
     columnsList.extend(["error","run_time"])
     schema = StructType(
@@ -203,7 +209,7 @@ def createErrorData(object:DataFrame) :
         )
     return spark.createDataFrame(spark.sparkContext.emptyRDD(), schema)
 #Function that validate rules going through the defined options
-def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, project:str,country: str,domain: str,subDomain: str,segment: str,area: str,error,dataDate:str,validData:str, Data,sendEmail,email,output):
+def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, project:str,country: str,domain: str,subDomain: str,segment: str,area: str,error,dataDate:str,validData:str, Data,email,output):
     runTime = datetime.datetime.now()
     errorData = createErrorData(object)
     rulesData:List = []
@@ -493,8 +499,6 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
                     writeDf(res,rules[code].get(JsonParts.Output))
         else:
             pass
-    if errorData.count() > Zero:
-        writeDf(errorData,error)
     try:
         if validData == "TRUE":
             finalData = object.join(errorData,on = Data.get(JsonParts.Fields), how = LeftAntiType)
@@ -515,9 +519,11 @@ def validateRules(object:DataFrame,rules:dict,registerAmount:int, entity: str, p
         dataDateWidget = dataDate
     try:
         emailData = validationData.groupBy("CARACTERISTICA_REGLA").mean("PORCENTAJE_CALIDAD_OK")
-        send_email(registerAmount,rulesNumber,output.get(JsonParts.Path),emailData,email)
+        send_email(registerAmount,rulesNumber,output.get(JsonParts.Path),emailData,dataDateWidget,pais_widget,entity,email)
     except:
         print("Se omite el envío de correo")
+    if errorData.count() > Zero:
+        writeDf(errorData,error)
     return validationData.select(
         DataDate.value(lit(dataDateWidget)),
         CountryId.value(lit(pais_widget.upper())),
