@@ -2,7 +2,7 @@ from motordecalidad.constants import *
 from pyspark.sql import DataFrame
 
 
-def send_email(registerAmount,rulesNumber,outputPath,data: DataFrame,receiver_email = "motordecalidadtlfhispan@gmail.com"):
+def send_email(registerAmount,rulesNumber,outputPath,data: DataFrame,date,country,entity,receiver_email = ["correostelefonicahispan@gmail.com"]):
     import smtplib
     from email.mime.text import MIMEText
     dataDict = data.collect()
@@ -11,14 +11,17 @@ def send_email(registerAmount,rulesNumber,outputPath,data: DataFrame,receiver_em
         ok_rules = ok_rules + "\n" + str(i[0]) + ":" + str(i[1]) + "\n"
     sslPort = 465  # For SSL
     smtp_server = 'smtp.gmail.com'
-    sender_email = "motordecalidadtlfhispan@gmail.com"
-    password = "ufbipwrjonvzuvsi"
+    sender_email = "correostelefonicahispan@gmail.com"
+    password = "xjldsavagzrobvqw"
     text = f"""\
     Hola,
     Su ejecucion del motor de calidad ha dado los siguientes resultados:
     Cantidad de Registros Evaluados: {registerAmount}
     Cantidad de Reglas Evaluadas: {rulesNumber}
     Tasa de éxito promedio por regla: {ok_rules}
+    País : {country}
+    Fecha de datos : {date}
+    Entidad evaluada: {entity}
     Se pueden consultar los resultados en {outputPath} """
     message = MIMEText(text)
     message["Subject"] = "Ejecucion de Motor de Calidad"
